==> faxtomail-ui-swing-1.0-sources.jar: com/franciaflex/faxtomail/ui/swing/content/reply/ReplyAttachmentModel.java <==
package com.franciaflex.faxtomail.ui.swing.content.reply;

/*
 * #%L
 * FaxToMail :: UI
 * $Id: ReplyAttachmentModel.java 660 2014-10-02 11:30:33Z kmorin $
 * $HeadURL: http://svn.codelutin.com/faxtomail/tags/faxtomail-1.0/faxtomail-ui-swing/src/main/java/com/franciaflex/faxtomail/ui/swing/content/reply/ReplyAttachmentModel.java $
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.franciaflex.faxtomail.persistence.entities.Attachment;
import com.franciaflex.faxtomail.persistence.entities.AttachmentFile;

/**
* @author Kevin Morin (Code Lutin)
*
*/
public class ReplyAttachmentModel {

    protected Attachment attachment;
    protected boolean original;
    protected String label;

    public ReplyAttachmentModel(Attachment attachment, boolean original, String label) {
        this.attachment = attachment;
        this.original = original;
        this.label = label;
    }

    public Attachment getAttachment() {
        return attachment;
    }

    public void setAttachment(Attachment attachment) {
        this.attachment = attachment;
    }

    public boolean isOriginal() {
        return original;
    }

    public void setOriginal(boolean original) {
        this.original = original;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public AttachmentFile getAttachmentFile() {
        return original ? attachment.getOriginalFile() : attachment.getEditedFile();
    }

    public long getLength() {
        return getAttachmentFile() != null ? getAttachmentFile().getLength() : 0;
    }

    @Override
    public String toString() {
        return label;
    }
}

==> faxtomail-ui-swing-1.1.6.1-sources.jar: com/franciaflex/faxtomail/ui/swing/content/reply/ReplyAttachmentModel.java <==
package com.franciaflex.faxtomail.ui.swing.content.reply;

/*
 * #%L
 * FaxToMail :: UI
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.franciaflex.faxtomail.persistence.entities.Attachment;
import com.franciaflex.faxtomail.persistence.entities.AttachmentFile;

/**
* @author Kevin Morin (Code Lutin)
*
*/
public class ReplyAttachmentModel {

    protected Attachment attachment;
    protected boolean original;
    protected String label;

    public ReplyAttachmentModel(Attachment attachment, boolean original, String label) {
        this.attachment = attachment;
        this.original = original;
        this.label = label;
    }

    public Attachment getAttachment() {
        return attachment;
    }

    public void setAttachment(Attachment attachment) {
        this.attachment = attachment;
    }

    public boolean isOriginal() {
        return original;
    }

    public void setOriginal(boolean original) {
        this.original = original;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public AttachmentFile getAttachmentFile() {
        return original ? attachment.getOriginalFile() : attachment.getEditedFile();
    }

    public long getLength() {
        return getAttachmentFile() != null ? getAttachmentFile().getLength() : 0;
    }

    @Override
    public String toString() {
        return label;
    }
}
